@@ -1,5 +1,7 @@
 # -*- coding: utf-8 -*-
-# Copyright (C) 2012-2015  Scott Koranda, 2015+ Duncan Macleod
+# Copyright (C) Scott Koranda (2012-2015)
+#               Lousiana State University (2015-2017)
+#               Cardiff University (2017-2022)
 #
 # This program is free software; you can redistribute it and/or modify it
 # under the terms of the GNU General Public License as published by the
@@ -18,17 +20,14 @@
 """Connection utilities for the GW datafind service.
 """
 
-from __future__ import (absolute_import, division)
-
 import os
 import re
 import socket
 import warnings
+from http import client as http_client
 from json import loads
-
-from six.moves import http_client
-from six.moves.urllib.error import HTTPError
-from six.moves.urllib.parse import urlparse
+from urllib.error import HTTPError
+from urllib.parse import urlparse
 
 from ligo import segments
 
