@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright Duncan Macleod 2018
+# Copyright (C) Cardiff University (2018-2022)
 #
 # This file is part of GWDataFind.
 #
@@ -20,3 +20,10 @@
 """
 
 __author__ = 'Duncan Macleod <duncan.macleod@ligo.org>'
+
+import pytest
+
+if pytest.__version__ < '3.0':
+    yield_fixture = pytest.yield_fixture
+else:
+    yield_fixture = pytest.fixture
