@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright (C) 2018  Duncan Macleod
+# Copyright (C) Cardiff University (2018-2022)
 #
 # This program is free software; you can redistribute it and/or modify it
 # under the terms of the GNU General Public License as published by the
@@ -20,23 +20,9 @@
 
 import os
 import tempfile
+from unittest import mock
 
-from six.moves import http_client
-
-import pytest
-
-try:
-    from unittest import mock
-except ImportError:  # python2.x
-    import mock
-
-if pytest.__version__ < '3.0':
-    yield_fixture = pytest.yield_fixture
-else:
-    yield_fixture = pytest.fixture
-
-HTTP_CLIENT = http_client.__name__
-HTTP_CONNECTION = '{0}.HTTPConnection'.format(HTTP_CLIENT)
+from . import yield_fixture
 
 
 @yield_fixture
@@ -45,8 +31,8 @@ def response():
 
     Yields the patch for `http.client.HTTPConnection.getresponse`
     """
-    with mock.patch('{0}.request'.format(HTTP_CONNECTION)), \
-         mock.patch('{0}.getresponse'.format(HTTP_CONNECTION)) as resp:
+    with mock.patch('http.client.HTTPConnection.request'), \
+         mock.patch('http.client.HTTPConnection.getresponse') as resp:
         yield resp
 
 
