@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright (C) 2018  Duncan Macleod
+# Copyright (C) Cardiff University (2018-2022)
 #
 # This program is free software; you can redistribute it and/or modify it
 # under the terms of the GNU General Public License as published by the
@@ -19,44 +19,24 @@
 """
 
 import json
-import os
-from io import BytesIO
-from operator import attrgetter
-
-from six import string_types
-from six.moves.urllib.error import HTTPError
-
-try:
-    from unittest import mock
-except ImportError:
-    import mock
+from unittest import mock
+from urllib.error import HTTPError
 
 import pytest
 
 from ligo.segments import (segment, segmentlist)
 
-from .. import utils
 from ..http import (
     HTTPConnection,
     HTTPSConnection,
 )
-
-LIGO_DATAFIND_SERVER = os.getenv('LIGO_DATAFIND_SERVER')
-
-def setup_module():
-    os.environ['LIGO_DATAFIND_SERVER'] = 'test.gwdatafind.com:123'
-
-
-def teardown_module():
-    os.environ.pop('LIGO_DATAFIND_SERVER')
-    if LIGO_DATAFIND_SERVER:
-        os.environ['LIGO_DATAFIND_SERVER'] = LIGO_DATAFIND_SERVER
+from . import yield_fixture
 
 
 def fake_response(output, status=200):
     resp = mock.Mock()
     resp.status = int(status)
-    if not isinstance(output, string_types):
+    if not isinstance(output, (str, bytes)):
         output = json.dumps(output)
     resp.read.return_value = output.encode('utf-8')
     return resp
@@ -75,9 +55,13 @@ class TestHTTPConnection(object):
         cls._create_connection_patch.stop()
 
     @classmethod
-    @pytest.fixture
+    @yield_fixture
     def connection(cls):
-        return cls.CONNECTION()
+        with mock.patch.dict(
+            "os.environ",
+            {"GWDATAFIND_SERVER": "test.gwdatafind.com:123"},
+        ):
+            yield cls.CONNECTION()
 
     def test_init(self, connection):
         assert connection.host == 'test.gwdatafind.com'
@@ -88,10 +72,9 @@ class TestHTTPConnection(object):
         jdata = connection.get_json('something')
         assert jdata['test'] == 1
 
-
     def test_ping(self, response, connection):
         response.return_value = fake_response('')
-        assert connection.ping() is 0
+        assert connection.ping() == 0
         response.return_value = fake_response('', 500)
         with pytest.raises(HTTPError):
             connection.ping()
@@ -172,7 +155,7 @@ class TestHTTPConnection(object):
         assert not wrngs.list
 
     def test_find_urls(self, response, connection):
-        files =  [
+        files = [
             'file:///tmp/X-test-0-10.gwf',
             'file:///tmp/X-test-10-10.gwf',
             'file:///tmp/X-test-20-10.gwf',
@@ -193,7 +176,7 @@ class TestHTTPConnection(object):
         assert not wrngs.list
 
     def test_find_frame_urls(self, response, connection):
-        files =  [
+        files = [
             'file:///tmp/X-test-0-10.gwf',
             'file:///tmp/X-test-10-10.gwf',
             'file:///tmp/X-test-20-10.gwf',
